function p=vappr(t,j)
% vappr: calculates vapor pressures of your compounds using Antoine data
% function p=vappr(t,j)
% Argument List:
% Argument   Gives
%    t      temperature in Tdeg.
%    j      indices of compounds in cnms that will
%            have their vapor pressures determined.
%           If this argument is omitted, all vapor pressures
%             will be found.
% Aabc must be set for the compounds with start301.
% Ex: start301
%   Be sure to specify you do want to use property data when you use 
%     start301 to specify the compounds.  
% If you specify C as your temperature unit
%     vappr(300)
%   will give the vapor pressures of all the compounds at 300C.
% The vapor pressure is given in kPa for the Antoine Data in sdata.

global Aabc
att=at(t);
if nargin==1
   p=(exp(Aabc(:,1)-Aabc(:,2)./(att+Aabc(:,3))))';
else
   p=(exp(Aabc(j,1)-Aabc(j,2)./(att+Aabc(j,3))))';
end

